@@ -24,9 +24,12 @@ class MiniECS:
     def __init__(self, address = 'localhost', port = 65535) -> None:
         self.address = address
         self.port = port
-        self.sock = None
+        self.sock = socket.create_connection((self.address, self.port))
         self.containers_list = []
 
+    def stop():
+        self.sock.close()
+
     def create_container(self, name: str):
 
         response = (False, "None")
@@ -37,8 +40,7 @@ class MiniECS:
 
             try:
                 # Send data
-                self.sock = socket.create_connection((self.address, self.port))
-                message = str.encode(name)
+                message = name.encode()
                 print('sending {!r}'.format(message))
                 self.sock.sendall(message)
 
@@ -51,10 +53,9 @@ class MiniECS:
 
             finally:
                 response = (True, "Success, the container with name '{}' was created.".format(name))
-                print('closing socket')
-                self.sock.close()
         
         else:
+
             response = (False, "Error, the container with name '{}' already exists.".format(name))
         
         return response
